@@ -343,7 +343,7 @@ CMD(keys, "keys", "", CMD_REF(list), "[PATTERN]",
           keypair kp;
           id hash_code;
           keys.get_key_pair(*i, kp);
-          key_hash_code(*i, kp.priv, hash_code);
+          key_hash_code(*i, kp.pub, hash_code);
           cout << hash_code << ' ' << *i << '\n';
         }
       cout << '\n';
@@ -636,8 +636,7 @@ namespace
     symbol const value("value");
     symbol const trust("trust");
 
-    symbol const public_hash("public_hash");
-    symbol const private_hash("private_hash");
+    symbol const hash("hash");
     symbol const public_location("public_location");
     symbol const private_location("private_location");
   }
@@ -646,13 +645,13 @@ namespace
 // Name: keys
 // Arguments: none
 // Added in: 1.1
+// Changed in: 10.0
 // Purpose: Prints all keys in the keystore, and if a database is given
 //   also all keys in the database, in basic_io format.
 // Output format: For each key, a basic_io stanza is printed. The items in
 //   the stanza are:
 //     name - the key identifier
-//     public_hash - the hash of the public half of the key
-//     private_hash - the hash of the private half of the key
+//     hash - the hash of the key
 //     public_location - where the public half of the key is stored
 //     private_location - where the private half of the key is stored
 //   The *_location items may have multiple values, as shown below
@@ -662,18 +661,16 @@ namespace
 //
 // Sample output:
 //               name "tbrownaw@gmail.com"
-//        public_hash [475055ec71ad48f5dfaf875b0fea597b5cbbee64]
-//       private_hash [7f76dae3f91bb48f80f1871856d9d519770b7f8a]
+//               hash [475055ec71ad48f5dfaf875b0fea597b5cbbee64]
 //    public_location "database" "keystore"
 //   private_location "keystore"
 //
 //              name "njs@pobox.com"
-//       public_hash [de84b575d5e47254393eba49dce9dc4db98ed42d]
+//              hash [de84b575d5e47254393eba49dce9dc4db98ed42d]
 //   public_location "database"
 //
 //               name "foo@bar.com"
-//        public_hash [7b6ce0bd83240438e7a8c7c207d8654881b763f6]
-//       private_hash [bfc3263e3257087f531168850801ccefc668312d]
+//               hash [7b6ce0bd83240438e7a8c7c207d8654881b763f6]
 //    public_location "keystore"
 //   private_location "keystore"
 //
@@ -691,8 +688,8 @@ CMD_AUTOMATE(keys, "",
 
   vector<rsa_keypair_id> dbkeys;
   vector<rsa_keypair_id> kskeys;
-  // public_hash, private_hash, public_location, private_location
-  map<string, boost::tuple<id, id,
+  // hash, public_location, private_location
+  map<string, boost::tuple<id,
                            vector<string>,
                            vector<string> > > items;
   if (db.database_specified())
@@ -708,7 +705,7 @@ CMD_AUTOMATE(keys, "",
       db.get_key(*i, pub_encoded);
       key_hash_code(*i, pub_encoded, hash_code);
       items[(*i)()].get<0>() = hash_code;
-      items[(*i)()].get<2>().push_back("database");
+      items[(*i)()].get<1>().push_back("database");
     }
 
   for (vector<rsa_keypair_id>::iterator i = kskeys.begin();
@@ -718,26 +715,22 @@ CMD_AUTOMATE(keys, "",
       id privhash, pubhash;
       keys.get_key_pair(*i, kp);
       key_hash_code(*i, kp.pub, pubhash);
-      key_hash_code(*i, kp.priv, privhash);
       items[(*i)()].get<0>() = pubhash;
-      items[(*i)()].get<1>() = privhash;
+      items[(*i)()].get<1>().push_back("keystore");
       items[(*i)()].get<2>().push_back("keystore");
-      items[(*i)()].get<3>().push_back("keystore");
     }
   basic_io::printer prt;
-  for (map<string, boost::tuple<id, id,
+  for (map<string, boost::tuple<id,
                                 vector<string>,
                                 vector<string> > >::iterator
          i = items.begin(); i != items.end(); ++i)
     {
       basic_io::stanza stz;
       stz.push_str_pair(syms::name, i->first);
-      stz.push_binary_pair(syms::public_hash, i->second.get<0>());
-      if (!i->second.get<1>()().empty())
-        stz.push_binary_pair(syms::private_hash, i->second.get<1>());
-      stz.push_str_multi(syms::public_location, i->second.get<2>());
-      if (!i->second.get<3>().empty())
-        stz.push_str_multi(syms::private_location, i->second.get<3>());
+      stz.push_binary_pair(syms::hash, i->second.get<0>());
+      stz.push_str_multi(syms::public_location, i->second.get<1>());
+      if (!i->second.get<2>().empty())
+        stz.push_str_multi(syms::private_location, i->second.get<2>());
       prt.print_stanza(stz);
     }
   output.write(prt.buf.data(), prt.buf.size());
