@@ -1,5 +1,5 @@
 // Copyright (C) 2005 Nathaniel Smith <njs@pobox.com>
-// Copyright (C) 2007 Zack Weinberg <zackw@panix.com>
+//               2007 Zack Weinberg <zackw@panix.com>
 //
 // This program is made available under the GNU GPL version 2.0 or
 // greater. See the accompanying file COPYING for details.
@@ -44,20 +44,21 @@ enum metachar {
 
 static string::const_iterator
 compile_charclass(string const & pat, string::const_iterator p,
-                  back_insert_iterator<string> & to)
+                  back_insert_iterator<string> & to,
+                  origin::type made_from)
 {
   string in_class;
   char bra = (char)META_CC_BRA;
 
   p++;
-  N(p != pat.end(),
+  E(p != pat.end(), made_from,
     F("invalid pattern '%s': unmatched '['") % pat);
 
   if (*p == '!' || *p == '^')
     {
       bra = (char)META_CC_INV_BRA;
       p++;
-      N(p != pat.end(),
+      E(p != pat.end(), made_from,
         F("invalid pattern '%s': unmatched '['") % pat);
     }
 
@@ -71,7 +72,7 @@ compile_charclass(string const & pat, string::const_iterator p,
         }
       // A dash at the beginning or end of the pattern is literal.
       else if (*p == '-'
-               && in_class.size() != 0
+               && !in_class.empty()
                && p+1 != pat.end()
                && p[1] != ']')
         {
@@ -83,39 +84,40 @@ compile_charclass(string const & pat, string::const_iterator p,
 
           // the cast is needed because boost::format will not obey the %x
           // if given a 'char'.
-          N((widen<unsigned int, char>(*p)) >= ' ',
+          E((widen<unsigned int, char>(*p)) >= ' ', made_from,
             F("invalid pattern '%s': control character 0x%02x is not allowed")
             % pat % (widen<unsigned int, char>(*p)));
 
           unsigned int start = widen<unsigned int, char>(in_class.end()[-1]);
           unsigned int stop = widen<unsigned int, char>(*p);
 
-          N(start != stop,
+          E(start != stop, made_from,
             F("invalid pattern '%s': "
               "one-element character ranges are not allowed") % pat);
-          N(start < stop,
+          E(start < stop, made_from,
             F("invalid pattern '%s': "
               "endpoints of a character range must be in "
               "ascending numeric order") % pat);
-          N(start < 0x80 && stop < 0x80,
+          E(start < 0x80 && stop < 0x80, made_from,
             F("invalid pattern '%s': cannot use non-ASCII characters "
               "in classes") % pat);
 
           L(FL("expanding range from %X (%c) to %X (%c)")
             % (start+1) % (char)(start+1) % stop % (char)stop);
-          
+
           for (unsigned int r = start + 1; r < stop; r++)
             in_class.push_back((char)r);
         }
       else
-        N(*p != '[', F("syntax error in '%s': "
-                       "character classes may not be nested") % pat);
+        E(*p != '[', made_from,
+          F("syntax error in '%s': "
+            "character classes may not be nested") % pat);
 
-      N((widen<unsigned int, char>(*p)) >= ' ',
+      E((widen<unsigned int, char>(*p)) >= ' ', made_from,
         F("invalid pattern '%s': control character 0x%02x is not allowed")
         % pat % (widen<unsigned int, char>(*p)));
 
-      N((widen<unsigned int, char>(*p)) < 0x80,
+      E((widen<unsigned int, char>(*p)) < 0x80, made_from,
         F("invalid pattern '%s': cannot use non-ASCII characters in classes")
         % pat);
 
@@ -123,10 +125,10 @@ compile_charclass(string const & pat, string::const_iterator p,
       p++;
     }
 
-  N(p != pat.end(),
+  E(p != pat.end(), made_from,
     F("invalid pattern '%s': unmatched '['") % pat);
 
-  N(in_class.size() != 0,
+  E(!in_class.empty(), made_from,
     F("invalid pattern '%s': empty character class") % pat);
 
   // minor optimization: one-element non-inverted character class becomes
@@ -146,7 +148,8 @@ compile_charclass(string const & pat, string::const_iterator p,
 // Compile one fragment of a glob pattern.
 
 static void
-compile_frag(string const & pat, back_insert_iterator<string> & to)
+compile_frag(string const & pat, back_insert_iterator<string> & to,
+             origin::type made_from)
 {
   unsigned int brace_depth = 0;
 
@@ -154,10 +157,10 @@ compile_frag(string const & pat, back_insert_iterator<string> & to)
     switch (*p)
       {
       default:
-        N((widen<unsigned int, char>(*p)) >= ' ',
+        E((widen<unsigned int, char>(*p)) >= ' ', made_from,
           F("invalid pattern '%s': control character 0x%02x is not allowed")
           % pat % (widen<unsigned int, char>(*p)));
-        
+
         *to++ = *p;
         break;
 
@@ -182,13 +185,13 @@ compile_frag(string const & pat, back_insert_iterator<string> & to)
       case '?':
         *to++ = META_QUES;
         break;
-        
+
       case '\\':
         p++;
-        N(p != pat.end(),
+        E(p != pat.end(), made_from,
           F("invalid pattern '%s': un-escaped \\ at end") % pat);
 
-        N((widen<unsigned int, char>(*p)) >= ' ',
+        E((widen<unsigned int, char>(*p)) >= ' ', made_from,
           F("invalid pattern '%s': control character 0x%02x is not allowed")
           % pat % (widen<unsigned int, char>(*p)));
 
@@ -196,11 +199,11 @@ compile_frag(string const & pat, back_insert_iterator<string> & to)
         break;
 
       case '[':
-        p = compile_charclass(pat, p, to);
+        p = compile_charclass(pat, p, to, made_from);
         break;
 
       case ']':
-        N(false, F("invalid pattern '%s': unmatched ']'") % pat);
+        E(false, made_from, F("invalid pattern '%s': unmatched ']'") % pat);
 
       case '{':
         // There's quite a bit of optimization we could be doing on
@@ -208,7 +211,7 @@ compile_frag(string const & pat, back_insert_iterator<string> & to)
         // nested alternatives; so we're not doing any of it now.
         // (Look at emacs's regexp-opt.el for inspiration.)
         brace_depth++;
-        N(brace_depth < 6,
+        E(brace_depth < 6, made_from,
           F("invalid pattern '%s': braces nested too deeply") % pat);
         *to++ = META_ALT_BRA;
         break;
@@ -221,25 +224,25 @@ compile_frag(string const & pat, back_insert_iterator<string> & to)
         break;
 
       case '}':
-        N(brace_depth > 0,
+        E(brace_depth > 0, made_from,
           F("invalid pattern '%s': unmatched '}'") % pat);
         brace_depth--;
         *to++ = META_ALT_KET;
         break;
       }
 
-  N(brace_depth == 0,
+  E(brace_depth == 0, made_from,
     F("invalid pattern '%s': unmatched '{'") % pat);
 }
 
 // common code used by the constructors.
 
 static inline string
-compile(string const & pat)
+compile(string const & pat, origin::type made_from)
 {
   string s;
   back_insert_iterator<string> to = back_inserter(s);
-  compile_frag(pat, to);
+  compile_frag(pat, to, made_from);
   return s;
 }
 
@@ -250,7 +253,7 @@ compile(vector<arg_type>::const_iterator const & beg,
   if (end - beg == 0)
     return "";
   if (end - beg == 1)
-    return compile((*beg)());
+    return compile((*beg)(), origin::user);
 
   string s;
   back_insert_iterator<string> to = back_inserter(s);
@@ -259,7 +262,7 @@ compile(vector<arg_type>::const_iterator const & beg,
   vector<arg_type>::const_iterator i = beg;
   for (;;)
     {
-      compile_frag((*i)(), to);
+      compile_frag((*i)(), to, origin::user);
       i++;
       if (i == end)
         break;
@@ -269,14 +272,20 @@ compile(vector<arg_type>::const_iterator const & beg,
   return s;
 }
 
-globish::globish(string const & p) : compiled_pattern(compile(p)) {}
-globish::globish(char const * p) : compiled_pattern(compile(p)) {}
+globish::globish(string const & p, origin::type made_from)
+  : origin_aware(made_from),
+    compiled_pattern(compile(p, made_from)) {}
+globish::globish(char const * p, origin::type made_from)
+  : origin_aware(made_from),
+    compiled_pattern(compile(p, made_from)) {}
 
 globish::globish(vector<arg_type> const & p)
-  : compiled_pattern(compile(p.begin(), p.end())) {}
+  : origin_aware(origin::user),
+    compiled_pattern(compile(p.begin(), p.end())) {}
 globish::globish(vector<arg_type>::const_iterator const & beg,
                  vector<arg_type>::const_iterator const & end)
-  : compiled_pattern(compile(beg, end)) {}
+  : origin_aware(origin::user),
+    compiled_pattern(compile(beg, end)) {}
 
 // Debugging.
 
@@ -334,28 +343,33 @@ find_next_subpattern(string::const_iterator p,
                        string::const_iterator pe,
                        bool want_alternatives)
 {
+  L(FL("Finding subpattern in '%s'") % decode(p, pe));
   unsigned int depth = 1;
   for (; p != pe; p++)
     switch (*p)
       {
-      default: break;
+      default:
+        break;
 
       case META_ALT_BRA:
-        depth++; break;
+        depth++;
+        break;
 
       case META_ALT_KET:
         depth--;
         if (depth == 0)
           return p+1;
+        break;
 
       case META_ALT_OR:
         if (depth == 1 && want_alternatives)
           return p+1;
+        break;
       }
 
   I(false);
 }
-                   
+
 
 static bool
 do_match(string::const_iterator sb, string::const_iterator se,
@@ -479,7 +493,7 @@ do_match(string::const_iterator sb, string::const_iterator se,
                 if (do_match(s, srest, psub, pnext - 1)
                     && do_match(srest, se, prest, pe))
                   return true;
-                
+
                 psub = pnext;
               }
             while (pnext < prest);
@@ -493,7 +507,7 @@ do_match(string::const_iterator sb, string::const_iterator se,
 bool globish::matches(string const & target) const
 {
   bool result;
-  
+
   // The empty pattern matches nothing.
   if (compiled_pattern.empty())
     result = false;
@@ -506,206 +520,6 @@ bool globish::matches(string const & target) const
   return result;
 }
 
-#ifdef BUILD_UNIT_TESTS
-#include "unit_tests.hh"
-
-UNIT_TEST(globish, syntax)
-{
-  struct tcase
-  {
-    char const * in;
-    char const * out;
-  };
-  tcase const good[] = {
-    { "a",   "a" },
-    { "\\a", "a" },
-    { "[a]", "a" },
-    { "[!a]", "[!a]" },
-    { "[^a]", "[!a]" },
-    { "[\\!a]", "[\\!a]" },
-    { "[\\^a]", "[\\^a]" },
-    { "[ab]", "[ab]" },
-    { "[a-b]", "[ab]" },
-    { "[a-c]", "[abc]" },
-    { "[ac-]", "[\\-ac]" },
-    { "[-ac]", "[\\-ac]" },
-    { "[+-/]", "[+\\,\\-./]" },
-
-    { "\xC2\xA1", "\xC2\xA1" }, // U+00A1 in UTF8
-    
-    { "*",   "*" },
-    { "\\*", "\\*" },
-    { "[*]", "\\*" },
-    { "?",   "?" },
-    { "\\?", "\\?" },
-    { "[?]", "\\?" },
-    { ",",   "\\," },
-    { "\\,", "\\," },
-    { "[,]", "\\," },
-    { "\\{", "\\{" },
-    { "[{]", "\\{" },
-    { "[}]", "\\}" },
-    { "\\[", "\\[" },
-    { "\\]", "\\]" },
-    { "\\\\", "\\\\" },
-
-    { "**",      "*" },
-    { "*?",      "?*" },
-    { "*???*?*", "????*" },
-    { "*a?*?b*", "*a??*b*" },
-
-    { "{a,b,c}d", "{a,b,c}d" },
-    { "foo{a,{b,c},?*}d", "foo{a,{b,c},?*}d" },
-    { "\\a\\b\\|\\{\\*", "ab|\\{\\*" },
-    { ".+$^{}", ".+$\\^{}" },
-    { "\\.\\+\\$\\^\\(\\)", ".+$\\^()" },
-    { 0, 0 }
-  };
-
-  char const * const bad[] = {
-    "[",
-    "[!",
-    "[\\",
-    "[\\]",
-    "[foo",
-    "[!foo",
-    "foo]",
-    "[\003]",
-    "[a-a]",
-    "[f-a]",
-    "[]",
-    "[\xC2\xA1]",
-    "[\xC2\xA1\xC2\xA2]",
-    "[\xC2\xA1-\xC2\xA2]",
-    "[-\xC2\xA1]",
-    "[[]",
-    "[]",
-
-    "\003",
-    "foo\\",
-    "{foo",
-    "{foo,bar{baz,quux}",
-    "foo}",
-    "foo,bar{baz,quux}}",
-    "{{{{{{{{{{a,b},c},d},e},f},g},h},i},j},k}",
-    0
-  };
-  char const dummy[] = "";
-
-  for (tcase const * p = good; p->in; p++)
-    {
-      globish g(p->in);
-      string s;
-      dump(g, s);
-      L(FL("globish syntax: %s -> %s [expect %s]") % p->in % s % p->out);
-      UNIT_TEST_CHECK(s == p->out);
-    }
-
-  for (char const * const * p = bad; *p; p++)
-    {
-      L(FL("globish syntax: invalid %s") % *p);
-      UNIT_TEST_CHECK_THROW(I(globish(*p).matches(dummy)), informative_failure);
-    }
-}
-
-UNIT_TEST(globish, from_vector)
-{
-  vector<arg_type> v;
-  v.push_back(arg_type("a"));
-  v.push_back(arg_type("b"));
-  v.push_back(arg_type("c"));
-  globish combined(v);
-  string s;
-  dump(combined, s);
-  UNIT_TEST_CHECK(s == "{a,b,c}");
-}
-
-UNIT_TEST(globish, simple_matches)
-{
-  UNIT_TEST_CHECK(globish("abc").matches("abc"));
-  UNIT_TEST_CHECK(!globish("abc").matches("aac"));
-
-  UNIT_TEST_CHECK(globish("a[bc]d").matches("abd"));
-  UNIT_TEST_CHECK(globish("a[bc]d").matches("acd"));
-  UNIT_TEST_CHECK(!globish("a[bc]d").matches("and"));
-  UNIT_TEST_CHECK(!globish("a[bc]d").matches("ad"));
-  UNIT_TEST_CHECK(!globish("a[bc]d").matches("abbd"));
-
-  UNIT_TEST_CHECK(globish("a[!bc]d").matches("and"));
-  UNIT_TEST_CHECK(globish("a[!bc]d").matches("a#d"));
-  UNIT_TEST_CHECK(!globish("a[!bc]d").matches("abd"));
-  UNIT_TEST_CHECK(!globish("a[!bc]d").matches("acd"));
-  UNIT_TEST_CHECK(!globish("a[!bc]d").matches("ad"));
-  UNIT_TEST_CHECK(!globish("a[!bc]d").matches("abbd"));
-
-  UNIT_TEST_CHECK(globish("a?c").matches("abc"));
-  UNIT_TEST_CHECK(globish("a?c").matches("aac"));
-  UNIT_TEST_CHECK(globish("a?c").matches("a%c"));
-  UNIT_TEST_CHECK(!globish("a?c").matches("a%d"));
-  UNIT_TEST_CHECK(!globish("a?c").matches("d%d"));
-  UNIT_TEST_CHECK(!globish("a?c").matches("d%c"));
-  UNIT_TEST_CHECK(!globish("a?c").matches("a%%d"));
-
-  UNIT_TEST_CHECK(globish("a*c").matches("ac"));
-  UNIT_TEST_CHECK(globish("a*c").matches("abc"));
-  UNIT_TEST_CHECK(globish("a*c").matches("abac"));
-  UNIT_TEST_CHECK(globish("a*c").matches("abbcc"));
-  UNIT_TEST_CHECK(globish("a*c").matches("abcbbc"));
-  UNIT_TEST_CHECK(!globish("a*c").matches("abcbb"));
-  UNIT_TEST_CHECK(!globish("a*c").matches("abcb"));
-  UNIT_TEST_CHECK(!globish("a*c").matches("aba"));
-  UNIT_TEST_CHECK(!globish("a*c").matches("ab"));
-
-  UNIT_TEST_CHECK(globish("*.bak").matches(".bak"));
-  UNIT_TEST_CHECK(globish("*.bak").matches("a.bak"));
-  UNIT_TEST_CHECK(globish("*.bak").matches("foo.bak"));
-  UNIT_TEST_CHECK(globish("*.bak").matches(".bak.bak"));
-  UNIT_TEST_CHECK(globish("*.bak").matches("fwibble.bak.bak"));
-
-  UNIT_TEST_CHECK(globish("a*b*[cd]").matches("abc"));
-  UNIT_TEST_CHECK(globish("a*b*[cd]").matches("abcd"));
-  UNIT_TEST_CHECK(globish("a*b*[cd]").matches("aabrd"));
-  UNIT_TEST_CHECK(globish("a*b*[cd]").matches("abbbbbbbccd"));
-  UNIT_TEST_CHECK(!globish("a*b*[cd]").matches("ab"));
-  UNIT_TEST_CHECK(!globish("a*b*[cd]").matches("abde"));
-  UNIT_TEST_CHECK(!globish("a*b*[cd]").matches("aaaaaaab"));
-  UNIT_TEST_CHECK(!globish("a*b*[cd]").matches("axxxxd"));
-  UNIT_TEST_CHECK(!globish("a*b*[cd]").matches("adb"));
-}
-
-UNIT_TEST(globish, complex_matches)
-{  {
-    globish_matcher m(globish("{a,b}?*\\*|"), globish("*c*"));
-    UNIT_TEST_CHECK(m("aq*|"));
-    UNIT_TEST_CHECK(m("bq*|"));
-    UNIT_TEST_CHECK(!m("bc*|"));
-    UNIT_TEST_CHECK(!m("bq|"));
-    UNIT_TEST_CHECK(!m("b*|"));
-    UNIT_TEST_CHECK(!m(""));
-  }
-  {
-    globish_matcher m(globish("{a,\\\\,b*}"), globish("*c*"));
-    UNIT_TEST_CHECK(m("a"));
-    UNIT_TEST_CHECK(!m("ab"));
-    UNIT_TEST_CHECK(m("\\"));
-    UNIT_TEST_CHECK(!m("\\\\"));
-    UNIT_TEST_CHECK(m("b"));
-    UNIT_TEST_CHECK(m("bfoobar"));
-    UNIT_TEST_CHECK(!m("bfoobarcfoobar"));
-  }
-  {
-    globish_matcher m(globish("*"), globish(""));
-    UNIT_TEST_CHECK(m("foo"));
-    UNIT_TEST_CHECK(m(""));
-  }
-  {
-    globish_matcher m(globish("{foo}"), globish(""));
-    UNIT_TEST_CHECK(m("foo"));
-    UNIT_TEST_CHECK(!m("bar"));
-  }
-}
-
-#endif // BUILD_UNIT_TESTS
 
 // Local Variables:
 // mode: C++
