@@ -1,4 +1,11 @@
-
+// Copyright (C) 2003 Graydon Hoare <graydon@pobox.com>
+//
+// This program is made available under the GNU GPL version 2.0 or
+// greater. See the accompanying file COPYING for details.
+//
+// This program is distributed WITHOUT ANY WARRANTY; without even the
+// implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+// PURPOSE.
 
 #include "base.hh"
 #include "lua.hh"
@@ -95,6 +102,17 @@ Lua::report_error()
   failed = true;
 }
 
+bool
+Lua::check_stack(int count)
+{
+  if (!lua_checkstack(st, count))
+    {
+      fail((FL("lua stack limit '%d' reached") % LUAI_MAXCSTACK).str());
+      return false;
+    }
+  return true;
+}
+
 // getters
 
 Lua &
@@ -251,7 +269,7 @@ Lua::begin()
       fail("istable() in begin");
       return *this;
     }
-  I(lua_checkstack (st, 1));
+  check_stack(1);
   lua_pushnil(st);
   return *this;
 }
@@ -265,7 +283,7 @@ Lua::next()
       fail("istable() in next");
       return false;
     }
-  I(lua_checkstack (st, 1));
+  if (!check_stack(1)) return false;
   if (lua_next(st, -2) != 0)
     {
       return true;
@@ -280,7 +298,7 @@ Lua &
 Lua::push_str(string const & str)
 {
   if (failed) return *this;
-  I(lua_checkstack (st, 1));
+  if (!check_stack(1)) return *this;
   lua_pushlstring(st, str.c_str(), str.size());
   return *this;
 }
@@ -289,7 +307,7 @@ Lua &
 Lua::push_int(int num)
 {
   if (failed) return *this;
-  I(lua_checkstack (st, 1));
+  if (!check_stack(1)) return *this;
   lua_pushnumber(st, num);
   return *this;
 }
@@ -298,7 +316,7 @@ Lua &
 Lua::push_double(double num)
 {
   if (failed) return *this;
-  I(lua_checkstack (st, 1));
+  if (check_stack(1)) return *this;
   lua_pushnumber(st, num);
   return *this;
 }
@@ -307,7 +325,7 @@ Lua &
 Lua::push_bool(bool b)
 {
   if (failed) return *this;
-  I(lua_checkstack (st, 1));
+  if (!check_stack(1)) return *this;
   lua_pushboolean(st, b);
   return *this;
 }
@@ -316,7 +334,7 @@ Lua &
 Lua::push_nil()
 {
   if (failed) return *this;
-  I(lua_checkstack (st, 1));
+  if (!check_stack(1)) return *this;
   lua_pushnil(st);
   return *this;
 }
@@ -325,7 +343,7 @@ Lua &
 Lua::push_table()
 {
   if (failed) return *this;
-  I(lua_checkstack (st, 1));
+  if (!check_stack(1)) return *this;
   lua_newtable(st);
   return *this;
 }
@@ -334,7 +352,7 @@ Lua &
 Lua::set_table(int idx)
 {
   if (failed) return *this;
-  I(lua_checkstack (st, 1));
+  if (!check_stack(1)) return *this;
   lua_settable(st, idx);
   return *this;
 }
@@ -351,7 +369,7 @@ Lua &
 Lua::call(int in, int out)
 {
   if (failed) return *this;
-  I(lua_checkstack (st, out));
+  if (!check_stack(out)) return *this;
   if (lua_pcall(st, in, out, 0) != 0)
     {
       report_error();
@@ -462,57 +480,59 @@ void add_functions(lua_State * st)
 
 LUAEXT(include, )
 {
-  const char *path = luaL_checkstring(L, -1);
-  N(path, F("%s called with an invalid parameter") % "Include");
+  const char *path = luaL_checkstring(LS, -1);
+  E(path, origin::user,
+    F("%s called with an invalid parameter") % "Include");
 
-  bool res = run_file(L, path);
+  bool res = run_file(LS, path);
 
-  lua_pushboolean(L, res);
+  lua_pushboolean(LS, res);
   return 1;
 }
 
 LUAEXT(includedir, )
 {
-  const char *pathstr = luaL_checkstring(L, -1);
-  N(pathstr, F("%s called with an invalid parameter") % "IncludeDir");
+  const char *pathstr = luaL_checkstring(LS, -1);
+  E(pathstr, origin::user,
+    F("%s called with an invalid parameter") % "IncludeDir");
 
-  run_directory(L, pathstr, "*");
-  lua_pushboolean(L, true);
+  run_directory(LS, pathstr, "*");
+  lua_pushboolean(LS, true);
   return 1;
 }
 
 LUAEXT(includedirpattern, )
 {
-  const char *pathstr = luaL_checkstring(L, -2);
-  const char *pattern = luaL_checkstring(L, -1);
-  N(pathstr && pattern,
+  const char *pathstr = luaL_checkstring(LS, -2);
+  const char *pattern = luaL_checkstring(LS, -1);
+  E(pathstr && pattern, origin::user,
     F("%s called with an invalid parameter") % "IncludeDirPattern");
 
-  run_directory(L, pathstr, pattern);
-  lua_pushboolean(L, true);
+  run_directory(LS, pathstr, pattern);
+  lua_pushboolean(LS, true);
   return 1;
 }
 
 LUAEXT(search, regex)
 {
-  const char *re = luaL_checkstring(L, -2);
-  const char *str = luaL_checkstring(L, -1);
+  const char *re = luaL_checkstring(LS, -2);
+  const char *str = luaL_checkstring(LS, -1);
 
   bool result = false;
   try {
-    result = pcre::regex(re).match(str);
-  } catch (informative_failure & e) {
-    lua_pushstring(L, e.what());
-    return lua_error(L);
+    result = pcre::regex(re, origin::user).match(str, origin::user);
+  } catch (recoverable_failure & e) {
+    lua_pushstring(LS, e.what());
+    return lua_error(LS);
   }
-  lua_pushboolean(L, result);
+  lua_pushboolean(LS, result);
   return 1;
 }
 
 LUAEXT(gettext, )
 {
-  const char *msgid = luaL_checkstring(L, -1);
-  lua_pushstring(L, gettext(msgid));
+  const char *msgid = luaL_checkstring(LS, -1);
+  lua_pushstring(LS, gettext(msgid));
   return 1;
 }
 
@@ -546,7 +566,7 @@ namespace
   {
     record_if_matches(string const & b, char const * p,
                       vector<string> & t)
-      : base(b + "/"), glob(p), target(t)
+      : base(b + "/"), glob(p, origin::user), target(t)
     { target.clear(); }
 
     virtual void consume(const char * component)
@@ -569,9 +589,9 @@ run_directory(lua_State * st, char const * pathstr, char const * pattern)
   switch (get_path_status(path))
     {
     case path::nonexistent:
-      N(false, F("Directory '%s' does not exist") % pathstr);
+      E(false, origin::user, F("Directory '%s' does not exist") % pathstr);
     case path::file:
-      N(false, F("'%s' is not a directory") % pathstr);
+      E(false, origin::user, F("'%s' is not a directory") % pathstr);
     case path::directory:
       break;
     }
@@ -593,7 +613,7 @@ run_directory(lua_State * st, char const * pathstr, char const * pattern)
         .loadfile(i->c_str())
         .call(0,1)
         .ok();
-      N(res, F("lua error while loading rcfile '%s'") % *i);
+      E(res, origin::user, F("lua error while loading rcfile '%s'") % *i);
       L(FL("'%s' is ok") % *i);
     }
 }
