@@ -652,7 +652,7 @@ resolve_merge_conflicts(lua_hooks & lua,
                         roster_t const & right_roster,
                         roster_merge_result & result,
                         content_merge_adaptor & adaptor,
-                        bool resolutions_given)
+                        const bool resolutions_given)
 {
   if (!result.is_clean())
     {
