@@ -1,5 +1,11 @@
-// 2007 Timothy Brownawell <tbrownaw@gmail.com>
-// GNU GPL V2 or later
+// Copyright (C) 2007 Timothy Brownawell <tbrownaw@gmail.com>
+//
+// This program is made available under the GNU GPL version 2.0 or
+// greater. See the accompanying file COPYING for details.
+//
+// This program is distributed WITHOUT ANY WARRANTY; without even the
+// implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+// PURPOSE.
 
 #include "base.hh"
 #include "outdated_indicator.hh"
@@ -85,30 +91,6 @@ outdated_indicator_factory::note_change()
   impl->note_change();
 }
 
-#ifdef BUILD_UNIT_TESTS
-#include "unit_tests.hh"
-
-UNIT_TEST(outdated_indicator, )
-{
-  outdated_indicator indicator;
-  {
-    outdated_indicator_factory factory;
-    UNIT_TEST_CHECK(indicator.outdated());
-    indicator = factory.get_indicator();
-    UNIT_TEST_CHECK(!indicator.outdated());
-    factory.note_change();
-    UNIT_TEST_CHECK(indicator.outdated());
-    factory.note_change();
-    factory.note_change();
-    indicator = factory.get_indicator();
-    UNIT_TEST_CHECK(!indicator.outdated());
-  }
-  UNIT_TEST_CHECK(indicator.outdated());
-}
-
-#endif
-
-
 // Local Variables:
 // mode: C++
 // fill-column: 76
@@ -116,4 +98,3 @@ UNIT_TEST(outdated_indicator, )
 // indent-tabs-mode: nil
 // End:
 // vim: et:sw=2:sts=2:ts=2:cino=>2s,{s,\:s,+s,t0,g0,^-2,e-2,n-2,p2s,(0,=s:
-
