@@ -28,6 +28,7 @@
 #include "constants.hh"
 #include "cycle_detector.hh"
 #include "database.hh"
+#include "dates.hh"
 #include "file_io.hh"
 #include "interner.hh"
 #include "paths.hh"
@@ -490,7 +491,7 @@ insert_into_db(database & db, data const & curr_data,
   {
     string tmp;
     global_pieces.build_string(next_lines, tmp);
-    next_data = data(tmp);
+    next_data = data(tmp, origin::internal);
   }
   delta del;
   diff(curr_data, next_data, del);
@@ -677,7 +678,8 @@ import_rcs_file_with_cvs(database & db, string const & filename,
     I(r.deltas.find(r.admin.head) != r.deltas.end());
 
     file_id fid;
-    file_data dat(r.deltatexts.find(r.admin.head)->second->text);
+    file_data dat(r.deltatexts.find(r.admin.head)->second->text,
+                  origin::user);
     calculate_ident(dat, fid);
 
     cvs.set_filename(filename, fid);
@@ -844,7 +846,7 @@ cvs_history::push_branch(string const & branch_name, bool private_branch)
   shared_ptr<cvs_branch> branch;
 
   string bname = base_branch + "." + branch_name;
-  I(stk.size() > 0);
+  I(!stk.empty());
 
   if (private_branch)
     {
@@ -1204,7 +1206,7 @@ import_cvs_repo(project_t & project,
                 branch_name const & branchname)
 
 {
-  N(!directory_exists(cvsroot / "CVSROOT"),
+  E(!directory_exists(cvsroot / "CVSROOT"), origin::user,
     F("%s appears to be a CVS repository root directory\n"
       "try importing a module instead, with 'cvs_import %s/<module_name>")
     % cvsroot % cvsroot);
@@ -1231,7 +1233,7 @@ import_cvs_repo(project_t & project,
 
   ticker n_revs(_("revisions"), "r", 1);
 
-  while (cvs.branches.size() > 0)
+  while (!cvs.branches.empty())
     {
       transaction_guard guard(project.db);
       map<string, shared_ptr<cvs_branch> >::const_iterator i = cvs.branches.begin();
@@ -1366,9 +1368,10 @@ cluster_consumer::store_auxiliary_certs(prepared_revision const & p)
     }
 
   project.put_standard_certs(keys, p.rid,
-                             branch_name(branchname),
-                             utf8(cvs.changelog_interner.lookup(p.changelog)),
-                             date_t::from_unix_epoch(p.time),
+                             branch_name(branchname, origin::user),
+                             utf8(cvs.changelog_interner.lookup(p.changelog),
+                                  origin::internal),
+                             date_t(p.time),
                              cvs.author_interner.lookup(p.author));
 }
 
@@ -1394,7 +1397,8 @@ cluster_consumer::build_cset(cvs_cluster const & c,
     {
       file_path pth = file_path_internal(cvs.path_interner.lookup(i->first));
 
-      file_id fid(cvs.file_version_interner.lookup(i->second.version));
+      file_id fid(cvs.file_version_interner.lookup(i->second.version),
+                  origin::internal);
       if (i->second.live)
         {
           map<cvs_path, cvs_version>::const_iterator e = live_files.find(i->first);
@@ -1408,7 +1412,8 @@ cluster_consumer::build_cset(cvs_cluster const & c,
             }
           else if (e->second != i->second.version)
             {
-              file_id old_fid(cvs.file_version_interner.lookup(e->second));
+              file_id old_fid(cvs.file_version_interner.lookup(e->second),
+                              origin::internal);
               L(FL("applying state delta on '%s' : '%s' -> '%s'")
                 % pth
                 % old_fid
