@@ -10,10 +10,9 @@
 #include "base.hh"
 #include <algorithm>
 #include <iterator>
-#include <iostream>
 #include <fstream>
-#include "vector.hh"
 #include <sstream>
+#include "vector.hh"
 
 #include <boost/format.hpp>
 #include <boost/circular_buffer.hpp>
@@ -37,9 +36,8 @@ using std::vector;
 
 using boost::format;
 
-extern string const & prog_name;
-static string real_prog_name;
-string const & prog_name = real_prog_name;
+// set by sanity::initialize
+std::string const * prog_name_ptr;
 
 string
 origin::type_to_string(origin::type t)
@@ -71,6 +69,7 @@ struct sanity::impl
   bool quiet;
   bool reallyquiet;
   boost::circular_buffer<char> logbuf;
+  std::string real_prog_name;
   std::string filename;
   std::string gasp_dump;
   bool already_dumping;
@@ -123,14 +122,18 @@ sanity::initialize(int argc, char ** argv, char const * lc_all)
   PERM_MM(string(lc_all));
   L(FL("set locale: LC_ALL=%s") % lc_all);
 
-  // find base name of executable and save in the prog_name global note that
+  // find base name of executable and save in the prog_name global. note that
   // this does not bother with conversion to utf8.
-  real_prog_name = argv[0];
-  if (real_prog_name.rfind(".exe") == prog_name.size() - 4)
-    real_prog_name = real_prog_name.substr(0, prog_name.size() - 4);
-  string::size_type last_slash = real_prog_name.find_last_of("/\\");
-  if (last_slash != string::npos)
-    real_prog_name.erase(0, last_slash+1);
+  {
+    string av0 = argv[0];
+    if (av0.size() > 4 && av0.rfind(".exe") == av0.size() - 4)
+      av0.erase(av0.size() - 4);
+    string::size_type last_slash = av0.find_last_of("/\\");
+    if (last_slash != string::npos)
+      av0.erase(0, last_slash+1);
+    imp->real_prog_name = av0;
+    prog_name_ptr = &imp->real_prog_name;
+  }
 }
 
 void
@@ -443,14 +446,14 @@ dump(string const & obj, string & out)
 }
 
 void
-print_var(std::string const & value, char const * var,
-          char const * file, int const line, char const * func)
+sanity::print_var(std::string const & value, char const * var,
+                  char const * file, int const line, char const * func)
 {
-  std::cout << (FL("----- begin '%s' (in %s, at %s:%d)\n")
-                % var % func % file % line)
-            << value
-            << (FL("\n-----   end '%s' (in %s, at %s:%d)\n\n")
-                % var % func % file % line);
+  inform_message((FL("----- begin '%s' (in %s, at %s:%d)")
+                  % var % func % file % line).str());
+  inform_message(value);
+  inform_message((FL("-----   end '%s' (in %s, at %s:%d)\n\n")
+                  % var % func % file % line).str());
 }
 
 void MusingBase::gasp_head(string & out) const
