@@ -18,3 +18,8 @@ check(mtn("automate", "identify", "testfile"), 0, true, false)
 canonicalize("stdout")
 check(samelines("stdout", { testfile_id }));
 
+-- ensure that it also gets properly encoded via stdio
+check(mtn("automate", "stdio"), 0, true, false, "l8:identify8:testfilee")
+canonicalize("stdout")
+check(samelines("stdout", { "0:0:l:41:" .. testfile_id }))
+
