@@ -13,7 +13,7 @@ check(mtn("-d", "cs-modern.db", "db", "load"), 0, false, false, true)
 check(mtn("-d", "cs-modern.db", "db", "migrate"), 0, false, false)
 
 check(mtn("-d", "cs-modern.db", "ls", "keys"), 1, false, false)
-check(mtn("-d", "cs-modern.db", "serve", "--bind=127.0.0.1:63219"), 1, false, false)
+check(mtn("-d", "cs-modern.db", "ls", "branches"), 1, false, false)
 
 
 check(get("rosterify.db.dumped", "stdin"))
@@ -21,7 +21,7 @@ check(mtn("-d", "ro-modern.db", "db", "load"), 0, false, false, true)
 check(mtn("-d", "ro-modern.db", "db", "migrate"), 0, false, false)
 
 check(mtn("-d", "ro-modern.db", "ls", "keys"), 1, false, false)
-check(mtn("-d", "ro-modern.db", "serve", "--bind=127.0.0.1:63219"), 1, false, false)
+check(mtn("-d", "ro-modern.db", "ls", "branches"), 1, false, false)
 
 -- arguably "db regenerate_caches" should go here too -- it's treated
 -- similarly.  But the test "schema_migration" tests for its behavior in this
