@@ -9,7 +9,7 @@ commit()
 
 remove("maude")
 
-check(mtn("drop", "maude"), 0, false, true)
+check(mtn("drop", "--bookkeep-only", "maude"), 0, false, true)
 check(qgrep('dropping maude from workspace manifest', "stderr"))
 
 check(mtn("status"), 0, true)
@@ -23,7 +23,7 @@ check(qgrep("skipping foobar", "stderr"))
 remove("harold")
 remove("places/cemetery")
 
-check(mtn("drop", "--missing"), 0, false, true)
+check(mtn("drop", "--bookkeep-only", "--missing"), 0, false, true)
 check(qgrep('dropping harold from workspace manifest', "stderr"))
 check(qgrep('dropping places/cemetery from workspace manifest', "stderr"))
 
